%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%GUILLERMO CARLOMAGNO
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [yTrimedLev, AlldropLow, AlldropUp, inflTrimed] = trimedInfl_w(Y, val0, W_implD1, ALP_Low, ALP_Up, useDiff)
                                     
    %NOTE: If useDiff is not 12, Y should be seasonal adjusted

    [T,N] = size(Y);
    PI = crecPrc(Y, useDiff);
    PI1 = crecPrc(Y, 1);
    
    %-------------Controls---------
        if (length(ALP_Low) ~= length(ALP_Up))
            error('alp_low and alp_up must have the same dimensio')
        end    
        if(~isscalar(ALP_Low) && length(ALP_Low)~=T)
            error('Y_sa and alp_low must have the same length')
        end
    %------------------------------    
    
    if isscalar(ALP_Low)
        ALP_Low = ones(T,1)*ALP_Low;
        ALP_Up = ones(T,1)*ALP_Up;
    end
    
    inflTrimed = nan(T,1);    
    AlldropLow = nan(N,T);
    AlldropUp = nan(N,T);
    idxAll = (1:N);
    for t =useDiff+1:T
        alp_low = ALP_Low(t); 
        alp_up = ALP_Up(t);
        
        pi = PI(t,:);
        idx_W0 = find(W_implD1(t,:)==0); idx_Wnan = find(isnan(W_implD1(t,:)));
        idxDrop = unique([find(isnan(pi)), idx_W0, idx_Wnan]);
        %idxDrop =[];
        piC = pi; piC(idxDrop)=[];
        idxAllC = idxAll; idxAllC(idxDrop)=[];        
        pi1C = PI1(t,:); pi1C(idxDrop)=[];
                
        [~, idxSort] = sort(piC);
        Ncorr = N - length(idxDrop);
        wC =  W_implD1(t, :); wC(idxDrop) = [];
        idxAllSort = idxAllC(idxSort);  
        
        %----------------
         w_sort = wC(idxSort);
         wCum = cumsum(w_sort');
         wcum_Low = wCum(wCum<=alp_low); qLow = length(wcum_Low) + double(max(wcum_Low)<alp_low);
         wcum_Up = wCum(wCum<=1-alp_up); qUp = Ncorr-length(wcum_Up);
        %----------------
                
        dropLow = idxSort(1:qLow);
        dropUp = idxSort(end-qUp+1: end);
        dropAll = [dropLow, dropUp];
        keep = setxor(idxSort, dropAll);
        useWprel = wC(keep); 
        useW = useWprel/sum(useWprel);
        %use_pi = pi1C(keep);  
        use_pi = piC(keep);  
        inflTrimed(t) = use_pi*useW';    
        %----------------------------
        AlldropUp(1:qUp,t) = idxAllSort(end-qUp+1: end);
        AlldropLow(1:qLow,t) = idxAllSort((1:qLow));      
        %[sum(W_implD1(t,  AlldropLow(1:qLow-1,t)))/sum(w_sort), max(wcum_Low)/sum(w_sort)]
    end
    
    yTrimedLev = nan(T,1); 
    yTrimedLev(useDiff) = val0;
    for t=useDiff+1:T
        yTrimedLev(t) = yTrimedLev(t-useDiff)*(1+inflTrimed(t));
    end

end %function
